@@ -10,6 +10,7 @@ import pandas as pd
 
 import ecl2df.grid
 import ecl2df.nnc
+from ecl2df import getLogger_ecl2csv
 from ecl2df.common import write_dframe_stdout_file
 
 from .eclfiles import EclFiles
@@ -222,7 +223,9 @@ def df(
             "DZ": "mean",
             "TRAN": "sum",
         }
-        aggregators = {key: aggregators[key] for key in aggregators if key in trans_df}
+        aggregators = {
+            key: value for (key, value) in aggregators.items() if key in trans_df
+        }
         trans_df = trans_df.groupby(pairname).agg(aggregators).reset_index()
 
         # Reinstate FIPNUM1 and FIPNUM2 (by splitting the pair, to get sorting for free)
@@ -300,8 +303,9 @@ def fill_parser(parser: argparse.ArgumentParser) -> argparse.ArgumentParser:
 
 def trans_main(args):
     """This is the command line API"""
-    if args.verbose:
-        logging.basicConfig(level=logging.INFO)
+    logger = getLogger_ecl2csv(  # pylint: disable=redefined-outer-name
+        __name__, vars(args)
+    )
     eclfiles = EclFiles(args.DATAFILE)
     trans_df = df(
         eclfiles,
