@@ -1,5 +1,6 @@
 import shutil
 from pathlib import Path
+from typing import Dict
 
 import pytest
 
@@ -17,23 +18,28 @@ from ert_shared.plugins.plugin_manager import ErtPluginManager
 
 import ecl2df.hook_implementations.jobs
 
-EXPECTED_JOBS = {
-    "ECL2CSV": "ecl2df/config_jobs/ECL2CSV",
-    "CSV2ECL": "ecl2df/config_jobs/CSV2ECL",
-}
+
+@pytest.fixture(name="expected_jobs")
+def fixture_expected_jobs(path_to_ecl2df: Path) -> Dict[str, Path]:
+    """Dictionary of installed jobs with location to job configuration"""
+    expected_job_names = [
+        "ECL2CSV",
+        "CSV2ECL",
+    ]
+    return {name: path_to_ecl2df / "config_jobs" / name for name in expected_job_names}
 
 
-def test_hook_implementations():
+def test_hook_implementations(expected_jobs):
     """Test that the expected jobs can be found using an ERT plugin manager"""
     plugin_m = ErtPluginManager(plugins=[ecl2df.hook_implementations.jobs])
 
     installable_jobs = plugin_m.get_installable_jobs()
-    for wf_name, wf_location in EXPECTED_JOBS.items():
+    for wf_name, wf_location in expected_jobs.items():
         assert wf_name in installable_jobs
-        assert installable_jobs[wf_name].endswith(wf_location)
         assert Path(installable_jobs[wf_name]).is_file()
+        assert installable_jobs[wf_name].endswith(str(wf_location))
 
-    assert set(installable_jobs.keys()) == set(EXPECTED_JOBS.keys())
+    assert set(installable_jobs.keys()) == set(expected_jobs.keys())
 
     expected_workflow_jobs = {}
     installable_workflow_jobs = plugin_m.get_installable_workflow_jobs()
@@ -44,25 +50,23 @@ def test_hook_implementations():
     assert set(installable_workflow_jobs.keys()) == set(expected_workflow_jobs.keys())
 
 
-def test_job_config_syntax():
+def test_job_config_syntax(expected_jobs):
     """Check for syntax errors made in job configuration files"""
-    src_path = Path(__file__).parent.parent
-    for _, job_config in EXPECTED_JOBS.items():
+    for _, job_config in expected_jobs.items():
         # Check (loosely) that double-dashes are enclosed in quotes:
-        with open(src_path / job_config) as f_handle:
-            for line in f_handle.readlines():
-                if not line.strip().startswith("--") and "--" in line:
-                    assert '"--' in line and " --" not in line
+        for line in Path(job_config).read_text(encoding="utf8").splitlines():
+            if not line.strip().startswith("--") and "--" in line:
+                assert '"--' in line and " --" not in line
 
 
 @pytest.mark.integration
-def test_executables():
+def test_executables(expected_jobs):
     """Test executables listed in job configurations exist in $PATH"""
-    src_path = Path(__file__).parent.parent
-    for _, job_config in EXPECTED_JOBS.items():
-        with open(src_path / job_config) as f_handle:
-            executable = f_handle.readlines()[0].split()[1]
-            assert shutil.which(executable)
+    for _, job_config in expected_jobs.items():
+        executable = (
+            Path(job_config).read_text(encoding="utf8").splitlines()[0].split()[1]
+        )
+        assert shutil.which(executable)
 
 
 def test_hook_implementations_job_docs():
