@@ -1,6 +1,7 @@
 """Test module for nnc2df"""
 
 import io
+import os
 import subprocess
 from pathlib import Path
 
@@ -10,13 +11,22 @@ import pytest
 from ecl2df import ecl2csv, faults, nnc, trans
 from ecl2df.eclfiles import EclFiles
 
+try:
+    import opm  # noqa
+
+    HAVE_OPM = True
+except ImportError:
+    HAVE_OPM = False
+
+
 TESTDIR = Path(__file__).absolute().parent
-DATAFILE = str(TESTDIR / "data/reek/eclipse/model/2_R001_REEK-0.DATA")
+REEK = str(TESTDIR / "data/reek/eclipse/model/2_R001_REEK-0.DATA")
+EIGHTCELLS = str(TESTDIR / "data/eightcells/EIGHTCELLS.DATA")
 
 
 def test_nnc2df():
     """Test that dataframes are produced"""
-    eclfiles = EclFiles(DATAFILE)
+    eclfiles = EclFiles(REEK)
     nncdf = nnc.df(eclfiles)
 
     assert not nncdf.empty
@@ -35,9 +45,15 @@ def test_nnc2df():
     assert len(nncdf) < prelen
 
 
+def test_no_nnc():
+    """Test nnc on an Eclipse case with no NNCs"""
+    eclfiles = EclFiles(EIGHTCELLS)
+    assert nnc.df(eclfiles).empty
+
+
 def test_nnc2df_coords():
     """Test that we are able to add coordinates"""
-    eclfiles = EclFiles(DATAFILE)
+    eclfiles = EclFiles(REEK)
     gnncdf = nnc.df(eclfiles, coords=True)
     assert not gnncdf.empty
     assert "X" in gnncdf
@@ -45,9 +61,10 @@ def test_nnc2df_coords():
     assert "Z" in gnncdf
 
 
+@pytest.mark.skipif(not HAVE_OPM, reason="Requires OPM")
 def test_nnc2df_faultnames():
     """Add faultnames from FAULTS keyword to connections"""
-    eclfiles = EclFiles(DATAFILE)
+    eclfiles = EclFiles(REEK)
     nncdf = nnc.df(eclfiles)
     faultsdf = faults.df(eclfiles.get_ecldeck())
 
@@ -69,11 +86,11 @@ def test_nnc2df_faultnames():
     # Remove I_x, J_x, K_x (and _y) which is not needed
 
 
-def test_df2ecl_editnnc(tmpdir):
+def test_df2ecl_editnnc(tmp_path):
     """Test generation of EDITNNC keyword"""
-    eclfiles = EclFiles(DATAFILE)
+    eclfiles = EclFiles(REEK)
     nncdf = nnc.df(eclfiles)
-    tmpdir.chdir()
+    os.chdir(tmp_path)
 
     nncdf["TRANM"] = 2
     editnnc = nnc.df2ecl_editnnc(nncdf, filename="editnnc.inc")
@@ -98,10 +115,11 @@ def test_df2ecl_editnnc(tmpdir):
     print(nnc.df2ecl_editnnc(nnc.df(eclfiles).head(4).assign(TRANM=0.1)))
 
 
-def test_main(tmpdir, mocker):
+@pytest.mark.skipif(not HAVE_OPM, reason="Requires OPM")
+def test_main(tmp_path, mocker):
     """Test command line interface"""
-    tmpcsvfile = tmpdir.join("nnc.csv")
-    mocker.patch("sys.argv", ["ecl2csv", "nnc", "-v", DATAFILE, "-o", str(tmpcsvfile)])
+    tmpcsvfile = tmp_path / "nnc.csv"
+    mocker.patch("sys.argv", ["ecl2csv", "nnc", "-v", REEK, "-o", str(tmpcsvfile)])
     ecl2csv.main()
 
     assert Path(tmpcsvfile).is_file()
@@ -111,10 +129,11 @@ def test_main(tmpdir, mocker):
     assert "TRAN" in disk_df
 
 
+@pytest.mark.skipif(not HAVE_OPM, reason="Requires OPM")
 def test_magic_stdout():
     """Test that we can pipe the output into a dataframe"""
     result = subprocess.run(
-        ["ecl2csv", "nnc", "-o", "-", DATAFILE], check=True, stdout=subprocess.PIPE
+        ["ecl2csv", "nnc", "-o", "-", REEK], check=True, stdout=subprocess.PIPE
     )
     df_stdout = pd.read_csv(io.StringIO(result.stdout.decode()))
     assert not df_stdout.empty
