@@ -1,5 +1,6 @@
 """Test module for satfunc2df"""
 
+import os
 import subprocess
 from pathlib import Path
 
@@ -10,14 +11,24 @@ import pytest
 from ecl2df import csv2ecl, ecl2csv, inferdims, satfunc
 from ecl2df.eclfiles import EclFiles
 
+try:
+    import opm  # noqa
+except ImportError:
+    pytest.skip(
+        "OPM is not installed, nothing relevant in here then",
+        allow_module_level=True,
+    )
+
+
 TESTDIR = Path(__file__).absolute().parent
-DATAFILE = str(TESTDIR / "data/reek/eclipse/model/2_R001_REEK-0.DATA")
+REEK = str(TESTDIR / "data/reek/eclipse/model/2_R001_REEK-0.DATA")
+EIGHTCELLS = str(TESTDIR / "data/eightcells/EIGHTCELLS.DATA")
 
 
 def test_ecldeck_to_satfunc_dframe():
     """Test that dataframes can be produced from a full Eclipse deck (the
     example Reek case)"""
-    eclfiles = EclFiles(DATAFILE)
+    eclfiles = EclFiles(REEK)
     satdf = satfunc.df(eclfiles.get_ecldeck())
 
     assert set(satdf["KEYWORD"]) == {"SWOF", "SGOF"}
@@ -44,7 +55,7 @@ def test_ecldeck_to_satfunc_dframe():
 def test_satfunc_roundtrip():
     """Test that we can produce a SATNUM dataframe from the Reek case, convert
     it back to an include file, and then reinterpret it to the same"""
-    eclfiles = EclFiles(DATAFILE)
+    eclfiles = EclFiles(EIGHTCELLS)
     satdf = satfunc.df(eclfiles.get_ecldeck())
     inc = satfunc.df2ecl(satdf)
     df_from_inc = satfunc.df(inc)
@@ -57,7 +68,7 @@ def test_satfunc_roundtrip():
 def test_df2ecl_order():
     """Test that we can control the keyword order in generated
     strings by the list supplied in keywords argument"""
-    eclfiles = EclFiles(DATAFILE)
+    eclfiles = EclFiles(REEK)
     satdf = satfunc.df(eclfiles.get_ecldeck())
 
     swof_sgof = satfunc.df2ecl(satdf, keywords=["SWOF", "SGOF"])
@@ -238,7 +249,7 @@ def test_str2df(string, expected_df):
     pd.testing.assert_frame_equal(df_from_inc, expected_df)
 
 
-def test_sgof_satnuminferrer(tmpdir, mocker):
+def test_sgof_satnuminferrer(tmp_path, mocker):
     """Test inferring of SATNUMS in SGOF strings"""
     sgofstr = """
 SGOF
@@ -254,7 +265,7 @@ SGOF
   1 1 0 0
 /
 """
-    tmpdir.chdir()
+    os.chdir(tmp_path)
     assert inferdims.guess_dim(sgofstr, "TABDIMS", 0) == 3
     sgofdf = satfunc.df(sgofstr)
     assert "SATNUM" in sgofdf
@@ -642,24 +653,24 @@ SGFN
     assert len(satnum_df) == 6
 
 
-def test_main_subparsers(tmpdir, mocker):
+def test_main_subparsers(tmp_path, mocker):
     """Test command line interface"""
-    tmpcsvfile = tmpdir.join("satfunc.csv")
-    mocker.patch("sys.argv", ["ecl2csv", "satfunc", DATAFILE, "-o", str(tmpcsvfile)])
+    tmpcsvfile = tmp_path / "satfunc.csv"
+    mocker.patch("sys.argv", ["ecl2csv", "satfunc", EIGHTCELLS, "-o", str(tmpcsvfile)])
     ecl2csv.main()
 
     assert Path(tmpcsvfile).is_file()
     disk_df = pd.read_csv(str(tmpcsvfile))
     assert not disk_df.empty
 
-    tmpcsvfile2 = tmpdir.join(".TMP-satfunc-swof.csv")
+    tmpcsvfile2 = tmp_path / ".TMP-satfunc-swof.csv"
     print(tmpcsvfile2)
     mocker.patch(
         "sys.argv",
         [
             "ecl2csv",
             "satfunc",
-            DATAFILE,
+            EIGHTCELLS,
             "--keywords",
             "SWOF",
             "--output",
@@ -673,9 +684,9 @@ def test_main_subparsers(tmpdir, mocker):
     assert set(disk_df["KEYWORD"].unique()) == {"SWOF"}
 
 
-def test_csv2ecl(tmpdir, mocker):
+def test_csv2ecl(tmp_path, mocker):
     """Test command line interface for csv to Eclipse include files"""
-    tmpdir.chdir()
+    os.chdir(tmp_path)
     tmpcsvfile = "satfunc.csv"
 
     swof_df = pd.DataFrame(
