@@ -5,17 +5,25 @@ import subprocess
 from pathlib import Path
 
 import pandas as pd
+import pytest
 
 from ecl2df import ecl2csv, wcon
 from ecl2df.eclfiles import EclFiles
 
+try:
+    import opm  # noqa
+except ImportError:
+    pytest.skip(
+        "OPM is not installed",
+        allow_module_level=True,
+    )
 TESTDIR = Path(__file__).absolute().parent
-DATAFILE = str(TESTDIR / "data/reek/eclipse/model/2_R001_REEK-0.DATA")
+EIGHTCELLS = str(TESTDIR / "data/eightcells/EIGHTCELLS.DATA")
 
 
 def test_wcon2df():
     """Test that dataframes are produced"""
-    eclfiles = EclFiles(DATAFILE)
+    eclfiles = EclFiles(EIGHTCELLS)
     wcondf = wcon.df(eclfiles.get_ecldeck())
 
     assert not wcondf.empty
@@ -207,10 +215,10 @@ WCONHIST
     assert "2001-05-07" in dates
 
 
-def test_main_subparsers(tmpdir, mocker):
+def test_main_subparsers(tmp_path, mocker):
     """Test command line interface"""
-    tmpcsvfile = tmpdir / ".TMP-wcondf.csv"
-    mocker.patch("sys.argv", ["ecl2csv", "wcon", DATAFILE, "-o", str(tmpcsvfile)])
+    tmpcsvfile = tmp_path / ".TMP-wcondf.csv"
+    mocker.patch("sys.argv", ["ecl2csv", "wcon", EIGHTCELLS, "-o", str(tmpcsvfile)])
     ecl2csv.main()
 
     assert Path(tmpcsvfile).is_file()
@@ -221,7 +229,7 @@ def test_main_subparsers(tmpdir, mocker):
 def test_magic_stdout():
     """Test that we can pipe the output into a dataframe"""
     result = subprocess.run(
-        ["ecl2csv", "wcon", "-v", "-o", "-", DATAFILE],
+        ["ecl2csv", "wcon", "-v", "-o", "-", EIGHTCELLS],
         check=True,
         stdout=subprocess.PIPE,
     )
